Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/browser.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/browser.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/browser.py	(revision 14310)
@@ -21,5 +21,5 @@
 from waeup.ikoba.customers.browser import (
     PDFContractSlip, CustomerBaseEditFormPage)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 class PDFContractSlip(PDFContractSlip):
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/contracts.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/contracts.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/contracts.py	(revision 14310)
@@ -26,45 +26,45 @@
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
 from waeup.ikoba.customers.contracts import ContractBase
-from ikobacustom.skeleton.interfaces import MessageFactory as _
-from ikobacustom.skeleton.customers.interfaces import (
-    ISkeletonContract, ISkeletonContractEdit, ISkeletonContractProcess,
-    ISkeletonContractOfficialUse)
+from ikobacustom.aaue.interfaces import MessageFactory as _
+from ikobacustom.aaue.customers.interfaces import (
+    IAAUEContract, IAAUEContractEdit, IAAUEContractProcess,
+    IAAUEContractOfficialUse)
 
 
-class SkeletonContract(ContractBase):
+class AAUEContract(ContractBase):
     """This is a sample contract.
     """
 
     grok.implements(
-        ISkeletonContractProcess,
-        ISkeletonContract,
-        ISkeletonContractEdit,
+        IAAUEContractProcess,
+        IAAUEContract,
+        IAAUEContractEdit,
         ICustomerNavigation)
 
     contract_category = 'sample'
 
-    form_fields_interface = ISkeletonContract
+    form_fields_interface = IAAUEContract
 
-    edit_form_fields_interface = ISkeletonContractEdit
+    edit_form_fields_interface = IAAUEContractEdit
 
-    ou_form_fields_interface = ISkeletonContractOfficialUse
+    ou_form_fields_interface = IAAUEContractOfficialUse
 
-    check_docs_interface = ISkeletonContract
+    check_docs_interface = IAAUEContract
 
-SkeletonContract = attrs_to_fields(SkeletonContract)
+AAUEContract = attrs_to_fields(AAUEContract)
 
 
 # Contracts must be importable. So we might need a factory.
-class SkeletonContractFactory(grok.GlobalUtility):
+class AAUEContractFactory(grok.GlobalUtility):
     """A factory for contracts.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonContract')
+    grok.name(u'waeup.AAUEContract')
     title = u"Create a new contract.",
     description = u"This factory instantiates new sample contract instances."
 
     def __call__(self, *args, **kw):
-        return SkeletonContract(*args, **kw)
+        return AAUEContract(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonContract)
+        return implementedBy(AAUEContract)
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/customer.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/customer.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/customer.py	(revision 14310)
@@ -25,31 +25,31 @@
 from waeup.ikoba.customers.customer import Customer
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomer
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.customers.interfaces import IAAUECustomer
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 
-class SkeletonCustomer(Customer):
+class AAUECustomer(Customer):
     """This is a customer container for the various objects
     owned by customers.
     """
-    grok.implements(ISkeletonCustomer, ICustomerNavigation)
-    grok.provides(ISkeletonCustomer)
+    grok.implements(IAAUECustomer, ICustomerNavigation)
+    grok.provides(IAAUECustomer)
 
-    form_fields_interface = ISkeletonCustomer
+    form_fields_interface = IAAUECustomer
 
-SkeletonCustomer = attrs_to_fields(SkeletonCustomer)
+AAUECustomer = attrs_to_fields(AAUECustomer)
 
 
-class SkeletonCustomerFactory(grok.GlobalUtility):
+class AAUECustomerFactory(grok.GlobalUtility):
     """A factory for customers.
     """
     grok.implements(IFactory)
     grok.name(u'waeup.Customer')
-    title = u"Create a new skeleton customer.",
-    description = u"This factory instantiates new skeleton customer instances."
+    title = u"Create a new aaue customer.",
+    description = u"This factory instantiates new aaue customer instances."
 
     def __call__(self, *args, **kw):
-        return SkeletonCustomer()
+        return AAUECustomer()
 
     def getInterfaces(self):
-        return implementedBy(SkeletonCustomer)
+        return implementedBy(AAUECustomer)
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/documents.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/documents.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/documents.py	(revision 14310)
@@ -25,14 +25,14 @@
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
 from waeup.ikoba.customers.documents import CustomerDocumentBase
-from ikobacustom.skeleton.interfaces import MessageFactory as _
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomerDocument
+from ikobacustom.aaue.interfaces import MessageFactory as _
+from ikobacustom.aaue.customers.interfaces import IAAUECustomerDocument
 
 
-class SkeletonCustomerDocument(CustomerDocumentBase):
+class AAUECustomerDocument(CustomerDocumentBase):
     """This is a sample customer document.
     """
 
-    grok.implements(ISkeletonCustomerDocument, ICustomerNavigation)
-    grok.provides(ISkeletonCustomerDocument)
+    grok.implements(IAAUECustomerDocument, ICustomerNavigation)
+    grok.provides(IAAUECustomerDocument)
 
     # Ikoba can store any number of files per Document object.
@@ -42,21 +42,21 @@
     filenames = ('sample',)
 
-    form_fields_interface = ISkeletonCustomerDocument
+    form_fields_interface = IAAUECustomerDocument
 
-SkeletonCustomerDocument = attrs_to_fields(SkeletonCustomerDocument)
+AAUECustomerDocument = attrs_to_fields(AAUECustomerDocument)
 
 
 # Customer documents must be importable. So we need a factory.
-class SkeletonCustomerDocumentFactory(grok.GlobalUtility):
+class AAUECustomerDocumentFactory(grok.GlobalUtility):
     """A factory for customer documents.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonCustomerDocument')
+    grok.name(u'waeup.AAUECustomerDocument')
     title = u"Create a new document.",
     description = u"This factory instantiates new sample document instances."
 
     def __call__(self, *args, **kw):
-        return SkeletonCustomerDocument(*args, **kw)
+        return AAUECustomerDocument(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonCustomerDocument)
+        return implementedBy(AAUECustomerDocument)
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/fileviewlets.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/fileviewlets.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/fileviewlets.py	(revision 14310)
@@ -23,5 +23,5 @@
     FileDisplay, FileUpload, Image)
 
-from ikobacustom.skeleton.customers.documents import SkeletonCustomerDocument
+from ikobacustom.aaue.customers.documents import AAUECustomerDocument
 
 from waeup.ikoba.customers.browser import (
@@ -39,5 +39,5 @@
     """
     grok.order(1)
-    grok.context(SkeletonCustomerDocument)
+    grok.context(AAUECustomerDocument)
     grok.view(DocumentManageFormPage)
     grok.require('waeup.manageCustomer')
@@ -61,5 +61,5 @@
     """
     grok.order(1)
-    grok.context(SkeletonCustomerDocument)
+    grok.context(AAUECustomerDocument)
     grok.require('waeup.viewCustomer')
     grok.view(DocumentDisplayFormPage)
@@ -74,5 +74,5 @@
     """
     grok.name('sample')
-    grok.context(SkeletonCustomerDocument)
+    grok.context(AAUECustomerDocument)
     grok.require('waeup.viewCustomer')
     download_name = u'sample'
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/interfaces.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/interfaces.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/interfaces.py	(revision 14310)
@@ -24,8 +24,8 @@
     ConCatProductSource, CustomerDocumentSource)
 from waeup.ikoba.products.productoptions import ProductOptionField
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 
-class ISkeletonCustomer(ICustomer):
+class IAAUECustomer(ICustomer):
     """Representation of a customer.
 
@@ -35,5 +35,5 @@
 
 
-class ISkeletonCustomerDocument(ICustomerDocument):
+class IAAUECustomerDocument(ICustomerDocument):
     """A customer document.
 
@@ -42,5 +42,5 @@
 # Customer contract interfaces
 
-class ISkeletonContract(IContract):
+class IAAUEContract(IContract):
     """A customer contract sample with document attached.
 
@@ -53,5 +53,5 @@
         )
 
-class ISkeletonContractOfficialUse(IIkobaObject):
+class IAAUEContractOfficialUse(IIkobaObject):
     """Interface for editing official use data.
 
@@ -63,5 +63,5 @@
         )
 
-class ISkeletonContractProcess(ISkeletonContract, ISkeletonContractOfficialUse):
+class IAAUEContractProcess(IAAUEContract, IAAUEContractOfficialUse):
     """Interface for processing contract data.
     """
@@ -75,5 +75,5 @@
         )
 
-class ISkeletonContractEdit(ISkeletonContract):
+class IAAUEContractEdit(IAAUEContract):
     """Interface for editing sample contract data by customers.
 
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/tests/test_browser.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/tests/test_browser.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/tests/test_browser.py	(revision 14310)
@@ -30,13 +30,13 @@
 from waeup.ikoba.customers.tests.test_batching import CustomerImportExportSetup
 from waeup.ikoba.customers.tests.test_browser import CustomersFullSetup
-from ikobacustom.skeleton.customers.export import (
-    SkeletonCustomerExporter,
-    SkeletonCustomerDocumentExporter,
-    SkeletonContractExporter)
-from ikobacustom.skeleton.customers.batching import (
-    SkeletonCustomerProcessor,
-    SkeletonCustomerDocumentProcessor,
-    SkeletonContractProcessor)
-from ikobacustom.skeleton.testing import FunctionalLayer, samples_dir
+from ikobacustom.aaue.customers.export import (
+    AAUECustomerExporter,
+    AAUECustomerDocumentExporter,
+    AAUEContractExporter)
+from ikobacustom.aaue.customers.batching import (
+    AAUECustomerProcessor,
+    AAUECustomerDocumentProcessor,
+    AAUEContractProcessor)
+from ikobacustom.aaue.testing import FunctionalLayer, samples_dir
 
 SAMPLE_IMAGE = os.path.join(os.path.dirname(__file__), 'test_image.jpg')
@@ -61,8 +61,8 @@
         IWorkflowState(customer).setState('started')
         self.app['customers'].addCustomer(customer)
-        document = createObject(u'waeup.SkeletonCustomerDocument')
+        document = createObject(u'waeup.AAUECustomerDocument')
         document.title = u'My first document'
         customer['documents'].addDocument(document)
-        contract = createObject(u'waeup.SkeletonContract')
+        contract = createObject(u'waeup.AAUEContract')
         contract.tc_dict = {'en':u'Hello World'}
         customer['contracts'].addContract(contract)
@@ -77,5 +77,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonCustomerExporter()
+        exporter = AAUECustomerExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -85,5 +85,5 @@
             'K1000000,aa@aa.aa,Beate,Mueller,,,123,f,0,,,started,[]\r\n')
         # We can reimport the file ...
-        processor = SkeletonCustomerProcessor()
+        processor = AAUECustomerProcessor()
         result = processor.doImport(
             self.outfile,
@@ -118,18 +118,18 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonCustomerDocumentExporter()
+        exporter = AAUECustomerDocumentExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
         self.assertMatches(result,
             'class_name,document_id,history,state,title,user_id\r\n'
-            'SkeletonCustomerDocument,%s,'
+            'AAUECustomerDocument,%s,'
             '[u\'2014-12-21 17:00:36 WAT - Document created by system\'],'
             'created,My first document,K1000000\r\n'
             % self.document.document_id)
         # We can reimport the file if we change the header (user_id -> customer_id)
-        processor = SkeletonCustomerDocumentProcessor()
+        processor = AAUECustomerDocumentProcessor()
         open(self.outfile, 'wb').write(
             'customer_id,class_name,document_id,state,title\r\n'
-            'K1000000,SkeletonCustomerDocument,%s,started,My first title\r\n'
+            'K1000000,AAUECustomerDocument,%s,started,My first title\r\n'
             % self.document.document_id)
         result = processor.doImport(
@@ -162,5 +162,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonContractExporter()
+        exporter = AAUEContractExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -169,15 +169,15 @@
             'fee_based,history,last_product_id,product_object,product_options,'
             'state,tc_dict,title,user_id,valid_from,valid_to\r\n'
-            'SkeletonContract,,sample,%s,,0,'
+            'AAUEContract,,sample,%s,,0,'
             '[u\'2014-12-21 22:26:00 WAT - Contract created by system\']'
             ',,,[],created,{\'en\': u\'Hello World\'},,K1000000,,\r\n'
             % self.contract.contract_id)
         # We can reimport the file if we change the header (user_id -> customer_id)
-        processor = SkeletonContractProcessor()
+        processor = AAUEContractProcessor()
         open(self.outfile, 'wb').write(
             'class_name,contract_category,contract_id,document_object,'
             'history,last_product_id,product_object,product_options,'
             'state,tc_dict,title,user_id\r\n'
-            'SkeletonContract,sample,%s,,'
+            'AAUEContract,sample,%s,,'
             '[u\'2014-12-21 22:26:00 WAT - Contract created by system\']'
             ',,,[],created,{\'en\': u\'Hello World\'},,K1000000\r\n'
@@ -221,6 +221,6 @@
     def setup_customizable_params(self):
         self._contract_category = u'sample'
-        self._document_factory = 'waeup.SkeletonCustomerDocument'
-        self._contract_factory = 'waeup.SkeletonContract'
+        self._document_factory = 'waeup.AAUECustomerDocument'
+        self._contract_factory = 'waeup.AAUEContract'
         return
 
@@ -304,6 +304,6 @@
     def setup_customizable_params(self):
         self._contract_category = u'sample'
-        self._document_factory = 'waeup.SkeletonCustomerDocument'
-        self._contract_factory = 'waeup.SkeletonContract'
+        self._document_factory = 'waeup.AAUECustomerDocument'
+        self._contract_factory = 'waeup.AAUEContract'
         return
 
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/tests/test_contract.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/tests/test_contract.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/tests/test_contract.py	(revision 14310)
@@ -28,7 +28,7 @@
 from waeup.ikoba.customers.contracts import ContractsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.contracts import SkeletonContract
-from ikobacustom.skeleton.customers.interfaces import ISkeletonContract
+from ikobacustom.aaue.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.aaue.customers.contracts import AAUEContract
+from ikobacustom.aaue.customers.interfaces import IAAUEContract
 
 
@@ -38,17 +38,17 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonContract, SkeletonContract)
-        verify.verifyClass(ICustomerNavigation, SkeletonContract)
-        verify.verifyObject(ISkeletonContract, SkeletonContract())
-        verify.verifyObject(ICustomerNavigation, SkeletonContract())
+        verify.verifyClass(IAAUEContract, AAUEContract)
+        verify.verifyClass(ICustomerNavigation, AAUEContract)
+        verify.verifyObject(IAAUEContract, AAUEContract())
+        verify.verifyObject(ICustomerNavigation, AAUEContract())
         return
 
     def test_addContract(self):
         container = ContractsContainer()
-        contract = createObject(u'waeup.SkeletonContract')
+        contract = createObject(u'waeup.AAUEContract')
         id = contract.contract_id
         container.addContract(contract)
         self.assertEqual(container[id], contract)
         self.assertRaises(TypeError, container.addContract, object())
-        self.assertEqual(contract.class_name, 'SkeletonContract')
+        self.assertEqual(contract.class_name, 'AAUEContract')
         return
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/tests/test_customer.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/tests/test_customer.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/tests/test_customer.py	(revision 14310)
@@ -17,5 +17,5 @@
 ##
 """
-Tests for skeleton customers.
+Tests for aaue customers.
 """
 import tempfile
@@ -30,14 +30,14 @@
 from waeup.ikoba.customers.container import CustomersContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.customer import SkeletonCustomer
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomer
+from ikobacustom.aaue.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.aaue.customers.customer import AAUECustomer
+from ikobacustom.aaue.customers.interfaces import IAAUECustomer
 
-class SkeletonCustomerTestCase(FunctionalTestCase):
+class AAUECustomerTestCase(FunctionalTestCase):
 
     layer = FunctionalLayer
 
     def setUp(self):
-        super(SkeletonCustomerTestCase, self).setUp()
+        super(AAUECustomerTestCase, self).setUp()
 
         # Prepopulate ZODB
@@ -52,13 +52,13 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonCustomer, SkeletonCustomer)
-        verify.verifyClass(ICustomerNavigation, SkeletonCustomer)
-        verify.verifyObject(ISkeletonCustomer, SkeletonCustomer())
-        verify.verifyObject(ICustomerNavigation, SkeletonCustomer())
+        verify.verifyClass(IAAUECustomer, AAUECustomer)
+        verify.verifyClass(ICustomerNavigation, AAUECustomer)
+        verify.verifyObject(IAAUECustomer, AAUECustomer())
+        verify.verifyObject(ICustomerNavigation, AAUECustomer())
         return
 
-    def test_addSkeletonCustomer(self):
+    def test_addAAUECustomer(self):
         customer = createObject(u'waeup.Customer')
-        verify.verifyObject(ISkeletonCustomer, customer)
+        verify.verifyObject(IAAUECustomer, customer)
         self.app['customers'].addCustomer(customer)
         self.assertEqual(customer.customer_id, 'K1000000')
@@ -68,4 +68,4 @@
     def tearDown(self):
         shutil.rmtree(self.dc_root)
-        super(SkeletonCustomerTestCase, self).tearDown()
+        super(AAUECustomerTestCase, self).tearDown()
         return
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/tests/test_document.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/tests/test_document.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/tests/test_document.py	(revision 14310)
@@ -28,7 +28,7 @@
 from waeup.ikoba.customers.documents import CustomerDocumentsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.documents import SkeletonCustomerDocument
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomerDocument
+from ikobacustom.aaue.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.aaue.customers.documents import AAUECustomerDocument
+from ikobacustom.aaue.customers.interfaces import IAAUECustomerDocument
 
 
@@ -38,17 +38,17 @@
 
     def test_interfaces(self):
-        verify.verifyClass(ISkeletonCustomerDocument, SkeletonCustomerDocument)
-        verify.verifyClass(ICustomerNavigation, SkeletonCustomerDocument)
-        verify.verifyObject(ISkeletonCustomerDocument, SkeletonCustomerDocument())
-        verify.verifyObject(ICustomerNavigation, SkeletonCustomerDocument())
+        verify.verifyClass(IAAUECustomerDocument, AAUECustomerDocument)
+        verify.verifyClass(ICustomerNavigation, AAUECustomerDocument)
+        verify.verifyObject(IAAUECustomerDocument, AAUECustomerDocument())
+        verify.verifyObject(ICustomerNavigation, AAUECustomerDocument())
         return
 
     def test_addDocument(self):
         container = CustomerDocumentsContainer()
-        document = createObject(u'waeup.SkeletonCustomerDocument')
+        document = createObject(u'waeup.AAUECustomerDocument')
         id = document.document_id
         container.addDocument(document)
         self.assertEqual(container[id], document)
         self.assertRaises(TypeError, container.addDocument, object())
-        self.assertEqual(document.class_name, 'SkeletonCustomerDocument')
+        self.assertEqual(document.class_name, 'AAUECustomerDocument')
         return
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/utils.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/utils.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/utils.py	(revision 14310)
@@ -25,7 +25,7 @@
     SUBMITTED, VERIFIED, REJECTED,
     EXPIRED, PROVISIONALLY)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
-class SkeletonCustomersUtils(CustomersUtils):
+class AAUECustomersUtils(CustomersUtils):
     """A collection of methods subject to customization.
     """
@@ -47,5 +47,5 @@
         #'CustomerPDFDocument': _('PDF Document'),
 
-        'SkeletonCustomerDocument': _('Skeleton Document'),
+        'AAUECustomerDocument': _('AAUE Document'),
         }
 
@@ -53,5 +53,5 @@
         #'SampleContract': _('Sample Contract'),
 
-        'SkeletonContract': _('Skeleton Contract'),
+        'AAUEContract': _('AAUE Contract'),
         }
 
@@ -62,4 +62,4 @@
     EXPORTER_NAMES = (
         'customers',
-        'skeletoncustomerdocuments',
-        'skeletoncontracts')
+        'aauecustomerdocuments',
+        'aauecontracts')

Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/batching.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/batching.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/batching.py	(revision 14310)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Batch processing for skeleton documents.
 """
 import grok
@@ -22,35 +22,35 @@
     CustomerProcessor,
     CustomerDocumentProcessorBase, ContractProcessorBase)
-from ikobacustom.skeleton.customers.interfaces import (
-    ISkeletonCustomer,
-    ISkeletonCustomerDocument, ISkeletonContract)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.customers.interfaces import (
+    IAAUECustomer,
+    IAAUECustomerDocument, IAAUEContract)
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 
-class SkeletonCustomerProcessor(CustomerProcessor):
+class AAUECustomerProcessor(CustomerProcessor):
     """A batch processor for ICustomer objects.
     """
-    util_name = 'skeletoncustomerprocessor'
+    util_name = 'aauecustomerprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Processor')
-    iface = ISkeletonCustomer
+    name = _('AAUE Customer Processor')
+    iface = IAAUECustomer
 
 
-class SkeletonCustomerDocumentProcessor(CustomerDocumentProcessorBase):
-    """A batch processor for ISkeletonCustomerDocument objects.
+class AAUECustomerDocumentProcessor(CustomerDocumentProcessorBase):
+    """A batch processor for IAAUECustomerDocument objects.
     """
-    util_name = 'skeletoncustomerdocumentprocessor'
+    util_name = 'aauecustomerdocumentprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Document Processor')
-    iface = ISkeletonCustomerDocument
-    factory_name = 'waeup.SkeletonCustomerDocument'
+    name = _('AAUE Customer Document Processor')
+    iface = IAAUECustomerDocument
+    factory_name = 'waeup.AAUECustomerDocument'
 
 
-class SkeletonContractProcessor(ContractProcessorBase):
-    """A batch processor for ISkeletonContract objects.
+class AAUEContractProcessor(ContractProcessorBase):
+    """A batch processor for IAAUEContract objects.
     """
-    util_name = 'skeletoncontractprocessor'
+    util_name = 'aauecontractprocessor'
     grok.name(util_name)
-    name = _('Skeleton Customer Contract Processor')
-    iface = ISkeletonContract
-    factory_name = 'waeup.SkeletonContract'
+    name = _('AAUE Customer Contract Processor')
+    iface = IAAUEContract
+    factory_name = 'waeup.AAUEContract'
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Batch processing for skeleton documents.
+"""Batch processing for aaue documents.
 """
 import grok
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/export.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/customers/export.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/customers/export.py	(revision 14310)
@@ -16,34 +16,34 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Exporters for skeleton customer objects and subobjects.
 """
 import grok
 from waeup.ikoba.customers.export import (
     CustomerExporter, CustomerDocumentExporterBase, ContractExporterBase)
-from ikobacustom.skeleton.customers.interfaces import (
-    ISkeletonCustomer, ISkeletonCustomerDocument, ISkeletonContractProcess)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.customers.interfaces import (
+    IAAUECustomer, IAAUECustomerDocument, IAAUEContractProcess)
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
-class SkeletonCustomerExporter(CustomerExporter):
+class AAUECustomerExporter(CustomerExporter):
     """Exporter for Customers.
     """
-    iface = ISkeletonCustomer
-    title = _(u'Skeleton Customers')
+    iface = IAAUECustomer
+    title = _(u'AAUE Customers')
 
 
-class SkeletonCustomerDocumentExporter(CustomerDocumentExporterBase):
+class AAUECustomerDocumentExporter(CustomerDocumentExporterBase):
     """Exporter for documents.
     """
-    grok.name('skeletoncustomerdocuments')
-    iface = ISkeletonCustomerDocument
-    title = _(u'Skeleton Customer Documents')
-    class_name = 'SkeletonCustomerDocument'
+    grok.name('aauecustomerdocuments')
+    iface = IAAUECustomerDocument
+    title = _(u'AAUE Customer Documents')
+    class_name = 'AAUECustomerDocument'
 
 
-class SkeletonContractExporter(ContractExporterBase):
+class AAUEContractExporter(ContractExporterBase):
     """Exporter for Contract instances.
     """
-    grok.name('skeletoncontracts')
-    iface = ISkeletonContractProcess
-    title = _(u'Skeleton Customer Contracts')
-    class_name = 'SkeletonContract'
+    grok.name('aauecontracts')
+    iface = IAAUEContractProcess
+    title = _(u'AAUE Customer Contracts')
+    class_name = 'AAUEContract'
@@ -16,34 +16,34 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Exporters for skeleton customer objects and subobjects.
+"""Exporters for aaue customer objects and subobjects.
 """
 import grok